Crate actix_easy_multipart
source ·Expand description
Typed multipart form extractor for actix-web.
Modules
Reads a field into memory.
Deserializes a field as JSON.
Writes a field to a temporary file on disk.
Deserializes a field from plain text.
Structs
Used to keep track of the remaining limits for the form and current field.
Typed
multipart/form-data extractor.MultipartForm extractor configuration.Enums
Traits
Trait that data types to be used in a multipart form struct should implement.
Trait that allows a type to be used in the
MultipartForm extractor. You should use
the MultipartForm to implement this for your struct.Derive Macros
Implements the
MultipartFormTrait for a struct so that it can be used with the
MultipartForm extractor.